#!perl -T

use strict;
use warnings;
use Test::More qw/ no_plan /;

use WebService::EveOnline;

my $API_KEY = $ENV{EVE_API_KEY} || 'abcdeABCDEabcdeABCDEabcdeABCDEabcdeABCDEabcdeABCDE12345678900000';
my $USER_ID = $ENV{EVE_USER_ID} || 1000000;

my $can_misc = undef;

ok( unlink('/tmp/webservice_eveonline.db') );

SKIP: {
	skip "Misc API currently unimplemented", 1 unless $can_misc;
	ok( 1 );
};
